SNCosmo
=======

_Python library for supernova cosmology_

[![Build Status](https://img.shields.io/travis/sncosmo/sncosmo.svg?style=flat-square&label=linux)](https://travis-ci.org/sncosmo/sncosmo)
[![Coverage Status](http://img.shields.io/coveralls/sncosmo/sncosmo.svg?style=flat-square)](https://coveralls.io/r/sncosmo/sncosmo?branch=master)
[![PyPI](https://img.shields.io/pypi/v/sncosmo.svg?style=flat-square)](https://pypi.python.org/pypi/sncosmo)
 <a href="http://ascl.net/1611.017"><img src="https://img.shields.io/badge/ascl-1611.017-blue.svg?colorB=262255" alt="ascl:1611.017" /></a>

**Documentation:** http://sncosmo.readthedocs.io

**Citing sncosmo:** [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.592747.svg)](https://doi.org/10.5281/zenodo.592747)
